abacusai.document_retriever_version — AbacusAI documentation

# abacusai.document_retriever_version

## Classes

`DocumentRetrieverVersion` | A version of document retriever.

## Module Contents

class abacusai.document_retriever_version.DocumentRetrieverVersion(client, documentRetrieverId=None, documentRetrieverVersion=None, createdAt=None, status=None, deploymentStatus=None, featureGroupId=None, featureGroupVersion=None, error=None, numberOfChunks=None, embeddingFileSize=None, warnings=None, resolvedConfig={})

  Bases: `abacusai.return_class.AbstractApiClass`

  A version of document retriever.

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - documentRetrieverId (str) – The unique identifier of the Document Retriever.

    - documentRetrieverVersion (str) – The unique identifier of the Document Retriever version.

    - createdAt (str) – When the Document Retriever was created.

    - status (str) – The status of Document Retriever version. It represents indexing status until indexing isn’t complete, and deployment status after indexing is complete.

    - deploymentStatus (str) – The status of deploying the Document Retriever version.

    - featureGroupId (str) – The feature group id associated with the document retriever.

    - featureGroupVersion (str) – The unique identifier of the feature group version at which the Document Retriever version is created.

    - error (str) – The error message when it failed to create the document retriever version.

    - numberOfChunks (int) – The number of chunks for the document retriever.

    - embeddingFileSize (int) – The size of embedding file for the document retriever.

    - warnings (list) – The warning messages when creating the document retriever.

    - resolvedConfig (DocumentRetrieverConfig) – The resolved configurations, such as default settings, for indexing documents.

  document_retriever_id
  document_retriever_version
  created_at
  status
  deployment_status
  feature_group_id
  feature_group_version
  error
  number_of_chunks
  embedding_file_size
  warnings
  resolved_config
  deprecated_keys
  __repr__()
  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict

  refresh()

    Calls describe and refreshes the current object’s fields

    Returns:

      The current object

    Return type:

      DocumentRetrieverVersion

  describe()

    Describe a document retriever version.

    Parameters:

      document_retriever_version (str) – A unique string identifier associated with the document retriever version.

    Returns:

      The document retriever version object.

    Return type:

      DocumentRetrieverVersion

  wait_for_results(timeout=3600)

    A waiting call until document retriever version is complete.

    Parameters:

      timeout (int) – The waiting time given to the call to finish, if it doesn’t finish by the allocated time, the call is said to be timed out.

  wait_until_ready(timeout=3600)

    A waiting call until the document retriever version is ready. It restarts the document retriever if it is stopped.

    Parameters:

      timeout (int) – The waiting time given to the call to finish, if it doesn’t finish by the allocated time, the call is said to be timed out.

  wait_until_deployment_ready(timeout=3600)

    A waiting call until the document retriever deployment is ready to serve.

    Parameters:

      timeout (int) – The waiting time given to the call to finish, if it doesn’t finish by the allocated time, the call is said to be timed out. Default value given is 3600 seconds.

  get_status()

    Gets the status of the document retriever version.

    Returns:

      A string describing the status of a document retriever version (pending, complete, etc.).

    Return type:

      str

  get_deployment_status()

    Gets the status of the document retriever version.

    Returns:

      A string describing the deployment status of a document retriever version (pending, deploying, etc.).

    Return type:

      str